.. _reference:

Reference
=========

The whole content of the library is contained within the only module `nani`.
This includes the types required to define a NumPy ``dtype``, the field helpers
when dealing with structured arrays, the functions, and the final output
structure :class:`~nani.Nani` returned from the main routine
:func:`~nani.resolve`.


.. toctree::
   :maxdepth: 2

   data_types
   field_helpers
   functions
   output_structure


.. seealso::

   A description of the usage of Nani as well as a few examples are available
   in the :ref:`tutorial` section.
